@@ -39,7 +39,7 @@ has 'reservation_id'	=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'owner_id'			=> ( is => 'ro', isa => 'Str', required => 1 );
 has 'group_set'			=> ( 
     is			=> 'ro', 
-    isa			=> 'ArrayRef[Net::Amazon::EC2::GroupSet]',
+    isa			=> 'ArrayRef[Net::Amazon::EC2::GroupSet] | Undef',
     required	=> 1,
     auto_deref	=> 1,
 );
@@ -53,6 +53,8 @@ has 'requester_id'		=> ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
 
 __PACKAGE__->meta->make_immutable();
 
+=back
+
 =head1 AUTHOR
 
 Jeff Kim <cpan@chosec.com>
@@ -65,4 +67,4 @@ under the same terms as Perl itself.
 =cut
 
 no Moose;
-1;
\ No newline at end of file
+1;
